%FILTRO QUE QUITA LA ENVOLVENTE.
%function d=invfilt(s,rp)
%Entradas:
%s:trama de 160 muestras de entrada.
%rp:coeficientes de reflexión decodificados.
%Salidas:
%d:trama de 160 muestras de salida sin envolvente.
function d=invfilt(s,rp)
uaux=zeros(1,8);
for k=1:160
   if(k<14)
      raux=rp(1:8);
   elseif(k<28)
      raux=rp(9:16);
   elseif(k<41)
      raux=rp(17:24);
   else
      raux=rp(25:32);
   end
	daux(1)=s(k);
	u(1)=s(k);
	for j=2:9
   	daux(j)=daux(j-1)+raux(j-1)*uaux(j-1);
   	u(j)=uaux(j-1)+raux(j-1)*daux(j-1);
	end
	d(k)=daux(9);
	uaux=u;
end